Learn R Programming

rif (version 0.2.0)

rif-package: R Client for Neuroscience Information Framework APIs

Description

R Client for Neuroscience Information Framework APIs

Arguments

API key

You now need an API key to use the NIF API. Steps:

  • Go to https://www.neuinfo.org/
  • If you don't have an account yet, register for an account.
  • Log in
  • Go to https://www.neuinfo.org/account/developer - you'll need to enter your password again
  • Create an API key
  • Store your API key ideally as an environment variable in .Renviron or similar. Or, you can save as an R option. (see ?Startup for help on env vars and R options). You can also pass in your API key to each function but that's not ideal.