Learn R Programming

rif (version 0.2.0)

rif_summary: Summary

Description

Summary

Usage

rif_summary(query, expandSynonyms = TRUE, expandAcronyms = FALSE,
  expandAbbrevs = FALSE, expandInferred = TRUE, key = NULL, ...)

Arguments

query
Query terms
expandSynonyms
(logical) Should recognized terms in the query have synonyms expanded? Default: TRUE
expandAcronyms
(logical) Default: FALSE
expandAbbrevs
(logical) Default: FALSE
expandInferred
(logical) Should recognized terms in the query have inferred terms expanded? Default: TRUE
key
(character) API key. required either passed in here or save as an env var or R option. see rif and Startup
...
Curl options passed on to HttpClient

Examples

Run this code
## Not run: ------------------------------------
# out <- rif_summary("cellular")
# out$query
# out$messages
# out$result$literatureSummary
# out$result$federationSummary$total
# out$result$federationSummary$categories
# head(out$result$federationSummary$results)
# 
# head( rif_summary("neuron")$result$federationSummary$results )
# head(
#  rif_summary("neuron", expandSynonyms=FALSE)$result$federationSummary$results
# )
# head(
#  rif_summary("neuron", expandAbbrevs=TRUE)$result$federationSummary$results
# )
# 
# rif_summary("cellular", verbose = TRUE)
## ---------------------------------------------

Run the code above in your browser using DataLab